package main

import (
	"encoding/json"
	"github.com/hyperledger/fabric/core/chaincode/shim"
	pb "github.com/hyperledger/fabric/protos/peer"
	"log"
)

//个人基本信息

type People struct {
	//区分数据类型
	DataType string `json:"dataType"`
	//身份证号码
	Id string `json:"id"`
	//性别
	Sex string `json:"Sex"`
	//姓名
	Name string `json:"name"`
	//出生地
	BrithLocation Location `json:"brithLocation"`
	//现居住地
	LiveLocation Location `json:"liveLocation"`
	//母亲身份证号
	MotherId string `json:"motherId"`
	//父亲身份证号
	FatherId string `json:"fatherId"`
}

type Location struct {
	//国家
	Country string `json:"country"`
	//省
	Province string `json:"province"`
	//城市
	City string `json:"city"`
	//镇
	Town string `json:"town"`
	//详细信息
	Detail string `json:"detail"`
}

//公民链

type CitizensChain struct {
}

//初始化方法

func (c *CitizensChain) Init(stub shim.ChaincodeStubInterface) pb.Response {
	function, _ := stub.GetFunctionAndParameters()
	if function != "init" {
		return shim.Error("方法名错误")
	}
	log.Println("初始化成功")
	return shim.Success(nil)
}

//链码交互入口

func (c *CitizensChain) Invoke(stub shim.ChaincodeStubInterface) pb.Response {
	//接受参数判断
	function, args := stub.GetFunctionAndParameters()
	//判断
	if function == "register" {
		//录入公民信息
		return c.register(stub, args)
	} else if function == "query" {
		//查询公民信息
		return c.query(stub, args)
	} else {
		return shim.Error("无效的方法名")
	}
	return shim.Success(nil)
}

//录入公民信息
//-c Args:[register, 身份证号, json]
//参数1：身份证号，是存储的key
//参数2：个人信心，当成valu来存储
func (c *CitizensChain) register(stub shim.ChaincodeStubInterface, args []string) pb.Response {
	if len(args) != 2 {
		return shim.Error("参数错误")
	}
	//接受身份证号
	key := args[0]
	//接受公民信息
	value := args[1]
	perple := People{}
	//转换
	err := json.Unmarshal([]byte(value), &perple)
	if err != nil {
		return shim.Error("注册失败，参数无法解析")
	}
	//更新世界状态
	err = stub.PutState(key, []byte(value))
	if err != nil {
		return shim.Error("世界状态更新失败")
	}
	return shim.Success(nil)
}

//查询公民信息
//-c Args:[query, 身份证号]
//参数1：身份证号，是存储的key
func (c *CitizensChain) query(stub shim.ChaincodeStubInterface, args []string) pb.Response {
	if len(args) < 1 {
		return shim.Error("参数错误")
	}
	//接受查询的key
	key := args[0]
	//去世界状态中查数据
	result, err := stub.GetState(key)
	if err != nil {
		return shim.Error("查询失败")
	}
	return shim.Success(result)
}
func main() {
	err := shim.Start(new(CitizensChain))
	if err != nil {
		log.Println(err)
	}
}
